Canada's Former Liberal Party Leader Offers Advice to Young Liberals | The New Republic
Author: Michael Ignatieff
Description: A letter to a young liberal.
Keywords: Politics, Politics, Canada, Liberal Party, Michael Ignatieff
Date: 2014-11-22T20:00:00-05:00

Politics

##### November 22, 2014

# I Wish Someone Had Told Me This Before I Became a Politician A letter to a young liberal

##### By Michael Ignatieff

Friend,

I was touched that you asked for my advice about going into politics. Anyone whose career in politics was nasty, brutish, and short—as mine was—is grateful that anyone thinks their opinion is worth hearing. All I’d claim is that my thoughts come with what Scott Fitzgerald called “the authority of failure.”

First of all, you need to know why you want it. You’d be amazed at how many people who go into politics can’t give you an honest answer to why they want it so badly.

All the best reasons for going into politics never really change: the desire for glory and fame and the chance to do something that really matters, that will make life better for a lot of people. You have to be one of those people with outsized, even laughable ambition, who want their convictions to mean something more than smart conversation at dinner tables. You have to have a sense of vocation, a belief that something must be done and that you’re the person to do it.

I had the vocation for politics. What I didn’t have was any aptitude for political combat. I took the attacks personally, which is a great mistake. It’s never personal: It’s just business. It was ever thus. You can prepare yourself for combat by going in as a staffer, watching it from the sidelines, as I did when I was in my twenties, but believe me, when you step in the ring yourself, the first punch always comes as a shock. That’s when you’ll know, as you snap your head back into place, whether your first instinct is fight or flight.

I went into politics thinking that, if I made arguments in good faith, I’d get a hearing. It’s a reasonable assumption, but it’s wrong. In five and a half years in politics up north, no one really bothered to criticize my ideas, such as they were. It was never my message that was the issue. It was always the messenger.

They will not attack what you say, so much as your right to say anything at all. In my case, they said I’d been out of the country too long, I wasn’t really “one of us,” but one of “them.” I was just visiting.

The attacks that are hardest to deal with are not the ones that are false, but the ones that have a sliver of truth. Being out of the country was nothing to be ashamed of, but it didn’t exactly help me to establish the trust that any politician must establish with voters.

Conjuring that trust requires authenticity. You can’t pretend to be somebody you’re not. People who say politics is acting get it wrong. You’re not playing a role. You’re on stage, true enough, but you’re playing yourself. People don’t have to identify with your life in order to vote for you, but they have to believe that you are who you say you are.

You will now list for me all the duplicitous villains who attained power without being authentic. You misunderstand me. A man like Nixon had authenticity aplenty. Voters knew exactly who he was: suspicious, manipulative, duplicitous, and just like them. They saw through him to themselves.

To be authentic, you have to own your life. All of it. John Kerry fell victim to the swift-boat attack because he couldn’t own the young lieutenant back from Vietnam who gave that damning testimony in Congress about the terrible things he witnessed up the Mekong Delta. He was unable, deep inside, to say, “Yes, I was that young lieutenant.” If you don’t want to vote for a man who criticized his country, go ahead. People, it turns out, will forgive candidates almost anything if they fight for their right to be themselves.

The real battle in politics is this battle over standing, your right to get a hearing as the person you are. Once the swift-boat attacks hit their target, once he failed to reply, Kerry could talk, but no one was listening. He had lost his standing. Once my opponents said I was just visiting, I lost mine. I could speak, but I couldn’t be heard.

So my advice is: Never let your opponents own your story. If you can’t do this truthfully, choose another business. And if you can’t defend your own life when people attack it, there are plenty of other lives you could choose that don’t require the same naked exposure.

It doesn’t pay, either, to pretend to be better than the business you’re in. You can’t succeed in politics if you give too much appearance of despising the low arts by which we govern ourselves. Fastidious distaste for the roughness and meanness of political life may work in a seminar room, but it’s fatal on the campaign trail.

> It is really something in life to be utterly disabused about human motive, and yet still come to work every day.

This distaste is common among people who’ve enjoyed success outside of politics, in academia or journalism or business, and who go into politics with the reasonable assumption that the prestige they achieved in their former profession should automatically transfer into politics. It doesn’t. People who think they’re entitled to standing—because they are brainy, rich, or famous—almost always lose. They forget you earn your standing, you are not entitled to it. That’s the best thing about democracy, the single reason why we’re not yet entirely governed by wealthy oligarchs.

I may have come into politics with an unacknowledged condescension toward the game and the people who played it, but I left with more respect for politicians than when I went in. The worst of them—the careerists and predators—you find in all professions. The best of them were a credit to democracy. They knew the difference between an adversary and an enemy, knew when to take half a loaf and when to insist on the whole bakery, knew when to trust their own judgment and when to listen to the people.

As I learned while watching wiser colleagues than I in a democratic legislature, it is really something in life to be utterly disabused about human motive, venality, capacity for double-crossing, and yet still come to work every day, trying to get something done.

Liberalism will become an enclave conviction of a shrinking minority unless those who call themselves liberal reconnect their faith in tolerance, equality, opportunity for all with the more difficult faith in the dirty, loud-mouthed, false, lying business of politics itself. This disdain is cynicism, masking as high principle. The ultimate allegiance of a democratic politician is not to party, not even to principle, but to the venal process called politics. So my final advice is this: Politics is not a vulgar means to a goal, it’s a noble life unto itself, and unless you love it, you can’t do it well. I didn’t get there, but I hope you will.

—Warmly, Michael

Michael Ignatieff teaches at Harvard’s Kennedy School. Fire and Ashes: Success and Failure in Politics is about his career as former leader of the Liberal Party of Canada.

Loading Related Articles...

#### More articles tagged as

Politicspolitics canada liberal party michael ignatieff
More Articles in Politics
The NYPD Freakout Isn't Just About Race. It's About Inequality, Too.
Steve Scalise's David Duke Scandal Says More About Republicans Than the Party Will Admit
Steve Scalise Made Compromises to Get Elected, Like Every Politician Does. Should He Lose His Seat Over Them?
The NYPD Is Using the Double-Murder to Dismiss Political Opponents—But Liberals Are Guilty of It, Too
Obama Went on the War Path in 2014 Not Just for His Legacy, But Hillary's Too
Popular Articles
Now
The Solar System Is Slowly Re-Arranging Itself
Male Nerds Think They're Victims Because They Have No Clue What Female Nerds Go Through
Stop Trying to Save the World
Oregon's Players Should Be Celebrated, Not Punished for Chanting "No Means No!"
At Last, Television Shows Have Figured Out What Sex Is Like for Women
Most Popular
Now

#### Oregon's Players Should Be Celebrated, Not Punished for Chanting "No Means No!"

#### Personality Matters More Than Intelligence at School

#### 'Selma' Ignores the Radical Grassroots Politics of the Civil Rights Movement

Loading
Loading

##### Sign Up For The New Republic Daily

Sign up now to get your dose of politics, culture, and big ideas with our free daily newsletter.

Sign Up
Signed up!
Article Tools
Loading Comments
Popular Articles
Now
The Solar System Is Slowly Re-Arranging Itself
Male Nerds Think They're Victims Because They Have No Clue What Female Nerds Go Through
Stop Trying to Save the World
Oregon's Players Should Be Celebrated, Not Punished for Chanting "No Means No!"
At Last, Television Shows Have Figured Out What Sex Is Like for Women
More Articles in Politics
The Solar System Is Slowly Re-Arranging Itself
Male Nerds Think They're Victims Because They Have No Clue What Female Nerds Go Through
Stop Trying to Save the World
Oregon's Players Should Be Celebrated, Not Punished for Chanting "No Means No!"
At Last, Television Shows Have Figured Out What Sex Is Like for Women
Share by e-mail
Friend's e-mails (separated by comma)
Your name
Your e-mail
Send yourself a copy
Personal message
Cancel
Send E-mail